@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10452 2017-11-07 08:45:22Z David $
+# $Id: views.py 10670 2017-12-23 06:15:34Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10452 $
+# $Revision: 10670 $
 
 from django.shortcuts import render_to_response, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
@@ -29,8 +29,7 @@ from Iuppiter.dispatch import ThreadPool
 from Iuppiter.extension.views import jsonpCallback
 from Iuppiter.Logging import createLogger
 
-from Theophrastus.models import (MailingList, Newsletter, 
-                                ContactMailingStatus, Contact)
+from Theophrastus.models import Newsletter, ContactMailingStatus, Contact
 from Theophrastus.cloud.Mailer import CloudMailer
 from Theophrastus.newsletter_extension.models import Header, Footer
 from Theophrastus.cloud.service import CloudService
@@ -49,36 +48,6 @@ def getDefaultFooterText(request):
     c = render_to_string('NewsletterDefaultFooter.html')
     return {'content': unicode(c)}
 
-@staff_member_required
-def createOrModifyHeader(request):
-    """
-    Create footer if not exists.
-    Redirect to header's change form page.
-    """
-    try:
-        header = Header.objects.all()[0]
-    except:
-        c = render_to_string('NewsletterDefaultHeader.html')
-        header = Header.objects.create(content=c)
-        header.save()
-    return redirect(
-        reverse('admin:newsletter_extension_header_change', args=[header.id]))
-
-@staff_member_required
-def createOrModifyFooter(request):
-    """
-    Create footer if not exists.
-    Redirect to footer's change form page.
-    """
-    try:
-        footer = Footer.objects.all()[0]
-    except:
-        c = render_to_string('NewsletterDefaultFooter.html')
-        footer = Footer.objects.create(content=c)
-        footer.save()
-    return redirect(
-        reverse('admin:newsletter_extension_footer_change', args=[footer.id]))
-
 @csrf_exempt
 @jsonpCallback(noPadding=True)
 def getNewsletterInfo(request):
